---

slug: /error
---

# Error codes

This topic describes error messages that may occur during obshell usage and provides solutions.

The error codes of obshell use strings with literal meanings to facilitate user understanding. When an operation fails, you can view the corresponding error code in the <code>obshell.log</code> log file and then refer to the <b>Solution</b> section in the following table for troubleshooting.

:::info
   If an error occurs while using obshell Dashboard, you can also view the HTTP response result by using the browser developer tools to obtain the error code (<code>errCode</code>). 
:::

| Error code | Error message | Description | Solution |
| --- | --- | --- | --- |
| Agent.AlreadyInitialized | Agent already initialized | The obshell node has already been initialized | Please contact the OceanBase technical support team for troubleshooting. |
| Agent.Current.UnderMaintenance | Agent is under maintenance | The current obshell node is under maintenance | Wait for the maintenance task to finish, or use task commands/APIs to roll back, retry, or skip the failed maintenance task. |
| Agent.Daemon.StartFailed | Daemon start failed | Failed to start the daemon process | Please contact the OceanBase technical support team for troubleshooting. |
| Agent.Daemon.ServeOnUnixSocketFailed | Daemon serve on socket listener failed | The daemon process failed to serve on the socket listener | Please contact the OceanBase technical support team for troubleshooting. |
| Agent.Identify.NotSupportOperation | '%s' is '%s', instead of '%s', does not support this operation | The current node identity does not support this operation | Please check the node identity and try again. |
| Agent.Identify.Unknown | Unknown agent identity: %s | The identity of the obshell node is unknown | Please contact the OceanBase technical support team for troubleshooting. |
| Agent.Info.NotEqual | Agent info not equal, input is %v, meta is %v | The obshell node information does not match | Please check the obshell node information. |
| Agent.IP.InconsistentWithOBServer | Agent IP inconsistent with observer | The obshell node IP does not match the seekdb node IP | Please check the IP configuration. |
| Agent.Load.OBConfigFailed | Load ob config from config file failed | Failed to load seekdb configuration from the config file | Please check the configuration file. |
| Agent.NotInitialized | Agent not initialized | The obshell node has not been initialized | Please initialize the corresponding obshell node first. |
| Agent.OBVersionNotSupported | Unsupported ob version '%s', the minimum supported version is '%s' | The current OceanBase seekdb version is not supported | Please use a supported OceanBase seekdb version. |
| Agent.OceanBase.DB.NotOcs | The current database is not ocs | The current database is not OCS | Please contact the OceanBase technical support team for troubleshooting. |
| Agent.OceanBase.NotHold | Agent is not holding OceanBase seekdb | The obshell node does not have an OceanBase seekdb connection | Please restart the obshell node and try again. |
| Agent.Oceanbase.Password.LoadFailed | Check password of root in sqlite failed | Failed to check the root password in SQLite | Please contact the OceanBase technical support team for troubleshooting. |
| Agent.OceanBase.Useless | The current database is useless | The current OceanBase seekdb is unavailable | Please check whether OceanBase seekdb is available. |
| Agent.Package.NotFound | Package %v is not found | The installation package could not be found | Please check the installation package and try again. |
| Agent.Rebuild.PortNotSame | Agent port is not the same, agent port in all_agents: %d, agent port now: %d | The obshell node ports are inconsistent | Rebuild obshell using the same port. |
| Agent.Rebuild.VersionNotSame | Agent version is not the same, agent version in all_agents: %s, agent version now: %s | obshell version inconsistency | Rebuild obshell using the same version. |
| Agent.Response.DataEmpty | Response data is empty | Response data is empty | Please contact the OceanBase technical support team for troubleshooting. |
| Agent.Response.DataFormatInvalid | Response data is not map | Response data format is invalid | Please contact the OceanBase technical support team for troubleshooting. |
| Agent.RPC.RequestError | Request [%s]%s to %s error: %v | Error occurred when sending internal request between nodes | Please contact the OceanBase technical support team for troubleshooting. |
| Agent.RPC.RequestFailed | Request [%s]%s to %s failed: %s | Failed to send internal request between nodes | Please contact the OceanBase technical support team for troubleshooting. |
| Agent.ServeOnTcpSocketFailed | Serve on tcp listener failed | Failed to serve on TCP listener | Please contact the OceanBase technical support team for troubleshooting. |
| Agent.ServeOnUnixSocketFailed | Serve on unix listener failed | Failed to serve on Unix listener | Please check system resources and permissions. |
| Agent.Sqlite.DB.NotInit | The sqlite db is not initialized | SQLite database not initialized | Please contact the OceanBase technical support team for troubleshooting. |
| Agent.Start.ObserverFailed | Start observer via flag failed | Failed to start seekdb | Please check seekdb configuration. |
| Agent.Start.WithInvalidInfo | Agent start with invalid info: %v | obshell start information is invalid | Please check the startup parameters. |
| Agent.TakeOverFailed | Take over or rebuild failed | Takeover or rebuild failed | Please contact the OceanBase technical support team for troubleshooting. |
| Agent.TCP.Listener.CreateFailed | Create tcp listerner failed | Failed to create TCP listener | Please contact the OceanBase technical support team for troubleshooting. |
| Agent.UnderMaintenanceDag | %s is under maintenance by dag [%s:%s] | Current obshell node is under maintenance | Wait for the maintenance task to complete, or use task commands/APIs to rollback, retry, or skip the failed maintenance task. |
| Agent.UnderMaintenance | %s is under maintenance | Current obshell node is under maintenance | Wait for the maintenance task to complete, or use task commands/APIs to rollback, retry, or skip the failed maintenance task. |
| Agent.Unix.Socket.Listener.CreateFailed | Create unix socket listerner failed | Failed to create Unix socket listener | Please contact the OceanBase technical support team for troubleshooting. |
| Agent.Upgrade.KillOldServerTimeout | Wait obshell server killed timeout | Timeout while waiting for obshell server termination | Please contact the OceanBase technical support team for troubleshooting. |
| Agent.Upgrade.ToLowerVersion | Target version %s is not greater than current version %s. Please verify if the params have been filled out correctly | Upgrade target version is not higher than the current version | Please verify that the parameters are correctly filled in and provide a valid target version. |
| Agent.Version.Inconsistent | obshell version is not consistent between %s(%s) and %s(%s) | obshell version inconsistency | Please use obshell with consistent versions. |
| Cli.FlagRequired | Required flag(s) "%s" not set | Required command options not set | Please configure all required options. |
| Cli.NotFound | %s not found | Corresponding resource not found | Please check if the resource exists. |
| Cli.OperationCancelled | Operation cancelled | Operation cancelled | Please re-execute the operation as needed. |
| Cli.UnixSocket.RequestFailed | Request unix-socket [%s]%s failed: %v | Unix socket request failed | Please contact the OceanBase technical support team for troubleshooting. |
| Cli.Upgrade.NoValidTargetBuildVersionFound | No valid target build version in pkg_directory found by '%s' | No valid target build version found | Please check the installation packages in the directory or provide a specific version number. |
| Cli.Upgrade.PackageNotFoundInPath | No valid %s package found in %s | No valid installation package found | Please check the package location. |
| Cli.UsageError | Incorrect usage: %s | Command usage error | Please check the command syntax. You can use the `-h`/`--help` option for help information on the corresponding command. |
| Common.BadRequest | Bad request: %v | Invalid request | Please check the request parameters and try again. |
| Common.BindJsonFailed | Bind JSON failed: %v | Failed to bind JSON | Please check the JSON format and try again. |
| Common.DirNotEmpty | Dir '%s' is not empty | Directory is not empty | Please check the directory and try again. |
| Common.FileNotExist | File '%s' does not exist | File does not exist | Please check the file path and try again. |
| Common.FilePermissionDenied | No read/write permission for file '%s' | No read/write permission for the file | Please ensure you have read/write permissions for the file before retrying. |
| Common.IllegalArgument | Illegal argument | Invalid argument | Please check the arguments and try again. |
| Common.InvalidAddress | '%s' is not a valid address | Invalid address | Please check the address and try again. |
| Common.InvalidIp | '%s' is not a valid IP address | Invalid IP address | Please check the IP address and try again. |
| Common.InvalidPath | Path '%s' is not valid: %s | Invalid path format | Please check the path format and try again. |
| Common.InvalidPort | The port '%s' is invalid, must in (1024, 65535]. | Invalid port | Please check the port. Valid port range is (1024, 65535]. |
| Common.InvalidTimeDuration | Time duration '%s' is invalid: %s | Invalid time duration | Please check the time duration and try again. |
| Common.NotFound | Element not found: %v | API request not found | Please check if the URI is correct. |
| Common.PathNotDir | '%s' is not a directory | The configured path is not a directory | Please check the path and try again. |
| Common.PathNotExist | '%s' does not exist | Path does not exist | Please check the path and try again. |
| Common.Unauthorized | Unauthorized | Authentication failed | Please check permissions and try again. |
| Common.Unexpected | Unexpected error: %s | Unexpected error | Please contact the OceanBase technical support team for troubleshooting. |
| Environment.DiskSpaceNotEnough | The remaining disk space is insufficient, the remaining disk space is %d, and the required disk space is %d | Insufficient disk space | Please free up disk space and try again, or switch to another disk with sufficient space. |
| Gorm.NoRowAffected | %s: no row affected | This operation did not make any changes to the seekdb | Please contact the OceanBase technical support team for troubleshooting. |
| Log.FileNameExtensionMismatched | File name '%s' extension mismatched | File extension does not match | Please contact the OceanBase technical support team for troubleshooting. |
| Log.FileNamePrefixMismatched | File name '%s' prefix mismatched | File name prefix does not match | Please contact the OceanBase technical support team for troubleshooting. |
| Log.WriteExceedMaxSize | Write length %d exceeds maximum file size %d | Write length exceeds maximum file size | Please contact the OceanBase technical support team for troubleshooting. |
| MySQL.Error | Occur error when execute sql | Error occurred while executing SQL | Please contact the OceanBase technical support team for troubleshooting. |
| OB.Binary.Version.Unexpected | Unexpected observer binary version. | seekdb version is unexpected | Please contact the OceanBase technical support team for troubleshooting. |
| SeekDB.MinorFreezeTimeout | Minor freeze timeout | Minor Freeze timeout | Please contact the OceanBase technical support team for troubleshooting. |
| SeekDB.NotInitialized | seekdb has not been initialized, please initialize it first | seekdb has not been initialized | Please contact the OceanBase technical support team for troubleshooting. |
| SeekDB.Password.Incorrect | The seekdb root password is incorrect | The provided seekdb root user password is incorrect | Please check the password and try again. |
| SeekDB.UnderMaintenance | seekdb is under maintenance, please try again later | seekdb is under maintenance | Wait for the maintenance task to complete, or use task commands/APIs to rollback, retry, or skip the failed maintenance task. |
| SeekDB.UnderMaintenanceWithDag | seekdb is under maintenance by DAG: %s | seekdb is under maintenance | Wait for the maintenance task to complete, or use task commands/APIs to rollback, retry, or skip the failed maintenance task. |
| SeekDB.Database.NotExist | Database %s of tenant %s | The specified database does not exist in seekdb | Please configure an existing database and try again. |
| SeekDB.Compaction.Status.NotIdle | seekdb is in '%s' status, operation not allowed | seekdb is not in idle status | Please wait until it is idle before trying the operation again. |
| SeekDB.Process.CheckFailed | Check seekdb process exist: %s | Failed to check seekdb process | Please contact the OceanBase technical support team for troubleshooting. |
| SeekDB.Process.NotExist | seekdb process does not exist | seekdb process does not exist | Please start the seekdb process and try again. |
| SeekDB.Variable.Empty | Variable name or value is empty. | Variable name or value is empty | Please check the configured variable and try again. |
| SeekDB.Variable.Invalid | Variable '%s' is invalid: %s | Invalid variable | Please check the variable and try again. |
| SeekDB.Variable.Name.Empty | Variable name is empty | Variable name is empty | Please provide a valid variable name. |
| SeekDB.Variable.NotExist | Variable '%s' is not found | Variable does not exist | Please check whether the variable exists. |
| SeekDB.User.Name.Empty | User name is empty | User name cannot be empty | Please provide a valid user name. |
| SeekDB.Privilege.NotSupported | Unsupported privilege %s | Operation privilege not supported | Please configure the required privileges for the user. |
| Package.Compression.NotSupported | Unsupported compression '%s', the supported compression is 'xz' | Unsupported package compression format | The supported compression format is `xz`. Please visit [OceanBase Download Center](https://en.oceanbase.com/softwarecenter) to download the corresponding installation package and re-upload. |
| Package.Format.Invalid | Unsupported payload format '%s', the supported payload format is 'cpio' | Unsupported payload format | The supported payload format is `cpio`. Please visit [OceanBase Download Center](https://en.oceanbase.com/softwarecenter) to download the corresponding installation package and re-upload. |
| Package.NameMismatch | RPM package name %s not match %s | Package name mismatch | Please check the package name. |
| Package.ReleaseFormat.Invalid | Release format %s is illegal | Release format is invalid | Please visit [OceanBase Download Center](https://en.oceanbase.com/softwarecenter) to download the corresponding installation package and re-upload. |
| Package.ReleaseInvalid | RPM package release %s not match format | Package release version does not meet format requirements | Please check the package format requirements. |
| Request.Body.Decrypt.AES.ContentLength.Invalid | Decrypted string length is not a multiple of the block size | Decrypted string length is not a multiple of the block size | Please check the encrypted body in the HTTP request (using AES encryption). |
| Request.Body.Decrypt.AES.KeyAndIv.Invalid | AES key and iv size error | AES key and IV size error | Please provide a valid key and IV in the request header. |
| Request.Body.Decrypt.AES.NoKey | No key for aes | Missing AES key | Please contact the OceanBase technical support team for troubleshooting. |
| Request.Body.Decrypt.SM4.NoKey | No key for sm4 | Missing SM4 key | Please contact the OceanBase technical support team for troubleshooting. |
| Request.Body.ReadFailed | Failed to read request body: %s | Failed to read HTTP request body | Please contact the OceanBase technical support team for troubleshooting. |
| Request.File.Missing | File %s in the request is missing: %s | Missing file in request | Please check the requested file. |
| Request.Header.NotFound | X-OCS-Header not found in http request header. | X-OCS-Header not found in HTTP request header | Please set the correct X-OCS-Header in the HTTP request header to authenticate. |
| Request.Header.Type.Invalid | Header type error | Header type error | HTTP header type is invalid; please check the HTTP request header and try again. |
| Request.Method.NotSupport | %s method not support | Method not supported | Please contact the OceanBase technical support team for troubleshooting. |
| Request.Query.Param.Empty | Query param %s is empty | Query parameter is empty | Please provide the path parameter and try again. |
| Request.Query.Param.Illegal | Query param %s is illegal | Query parameter is invalid | Please provide a valid query parameter and try again. |
| Security.Authentication.Expired | Authentication expired | Authentication information has expired | Please update the authentication information and try again. |
| Security.Authentication.File.Sha256Mismatch | File sha256 mismatch | File SHA256 value mismatch | The file in the request does not match the SHA256 in the HTTP header. Please check and re-upload. |
| Security.Authentication.Header.DecryptFailed | Decrypt http header failed: %s | Failed to decrypt HTTP request header | Please check if the encryption public key is correct. |
| Security.Authentication.Header.UriMismatch | URI mismatch | URI in request header does not match actual request URI | Please check the request URI set in the HTTP header and try again. |
| Security.Authentication.IncorrectSeekDBPassword | seekdb root password is incorrect | Incorrect root user password in seekdb instance | Please check the root user password in seekdb and try again after confirming it is correct. |
| Security.Authentication.Timestamp.Invalid | Invalid timestamp: %s, err: %s | Invalid timestamp | Please provide a valid timestamp in the HTTP header and try again. |
| Security.Authentication.Unauthorized | Authentication failed | Authentication failed | Please check your request and try again. |
| Security.User.PermissionDenied | Permission denied | Insufficient user permissions | Please contact the OceanBase technical support team for troubleshooting. |
| Task.Dag.Operator.CancelFinishedDag | Failed to cancel dag: dag is finished | Cannot cancel a finished DAG | Only DAGs in the RUNNING state can be canceled. |
| Task.Dag.Operator.CancelNotAllowed | Failed to cancel dag: node %s can not cancel | The DAG contains nodes that cannot be canceled | Please contact the OceanBase technical support team for troubleshooting. |
| Task.Dag.Operator.NotSupport | Not support operator %s | Unsupported DAG operation | Please perform a supported task operation. |
| Task.Dag.Operator.PassNotAllowed | Failed to pass dag: node %s can not pass | The DAG contains nodes that cannot be skipped | Please contact the OceanBase technical support team for troubleshooting. |
| Task.Dag.Operator.PassNotFailedDag | Failed to pass dag: dag is not failed | Cannot skip a DAG that is not in the failed state | Only failed DAGs can be skipped. |
| Task.Dag.Operator.RetryNotAllowed | Failed to set dag retry: node %s can not retry | The DAG contains nodes that cannot be retried | Please contact the OceanBase technical support team for troubleshooting. |
| Task.Dag.Operator.RetryNotFailedDag | Failed to set dag retry: dag state is not failed | Cannot retry a DAG that is not in the failed state | Only failed DAGs can be retried. |
| Task.Dag.Operator.RollbackNotAllowed | Failed to set dag rollback: node %s can not rollback | The DAG contains nodes that cannot be rolled back | Please contact the OceanBase technical support team for troubleshooting. |
| Task.Dag.Operator.RollbackNotFailedDag | Failed to set dag rollback: dag state is not failed | Cannot roll back a DAG that is not in the failed state | Only failed DAGs can be rolled back. |
| Task.Dag.PassTimeout | Pass %d timeout after %d seconds | Task skip operation timed out | Please contact the OceanBase technical support team for troubleshooting. |
| Task.Dag.State.Invalid | Invalid dag state '%d' | Invalid task state | Please contact the OceanBase technical support team for troubleshooting. |
| Task.Data.ConvertFailed | Convert %s failed: %s | Failed to convert task data | Please contact the OceanBase technical support team for troubleshooting. |
| Task.Data.NotSet | Data %s is not set | Required task data not set | Please contact the OceanBase technical support team for troubleshooting. |
| Task.GenericID.Invalid | Invalid id: %s | Invalid generic ID | Please provide a valid generic ID. |
| Task.LocalData.ConvertFailed | Convert %s failed: %s | Failed to convert local task data | Please check the local data format and try again. |
| Task.LocalData.NotSet | Task local data %s not set | Required local task data not set | Please contact the OceanBase technical support team for troubleshooting. |
| Task.Node.Operator.NotSupport | Not support operator %s | Unsupported operation | Please perform a supported task operation. |
| Task.Node.Operator.PassNotAllowed | Failed to pass node: node %s can not pass | Task node cannot be skipped | Task node cannot be skipped. |
| Task.Node.Operator.PassNotFailedDag | Failed to pass node: assigned dag is not failed | Cannot skip task node when DAG is not failed | Only failed task nodes can be skipped. |
| Task.Node.Operator.PassNotFailedNode | Failed to pass node: node %s is not failed | Cannot skip a task node that is not failed | Only failed task nodes can be skipped. |
| Task.NotFound | Task not found: %v | Task not found | Please verify the task ID and try again. |
| Task.Param.ConvertFailed | Convert %s failed: %s | Failed to convert task parameter | Please contact the OceanBase technical support team for troubleshooting. |
| Task.Param.NotSet | Param %s is not set | Required task parameter not set | Please contact the OceanBase technical support team for troubleshooting. |
| Task.RemoteTask.Failed | Remote task %s %s failed | Remote task failed | Please contact the OceanBase technical support team for troubleshooting. |
| Task.SubDag.NotAllAdvanced | Sub dag of agents: %v not advanced, main dag failed | Some Agent subtasks failed to advance | Please check and resolve the blocked subtasks. |
| Task.SubDag.NotAllCreated | Sub dag of agents: %v not created, main dag failed | Some Agent subtasks failed to be created | Please check the availability and connectivity of the Agents. |
| Task.SubDag.NotAllPassed | Not all sub dag passed, main dag failed | Some Agent subtasks failed to be skipped | Please check and resolve the failed subtasks. |
| Task.SubDag.NotAllReady | Sub dag of agents: %v not ready, can not advance main dag | Some Agent subtasks are not ready | Please wait until all subtasks are ready, or check for issues. |
| Task.SubDag.NotAllSucceed | Sub dag of agents: %v failed, main dag failed | Some Agent subtasks failed | Please check and resolve the failed subtasks. |
| Task.Template.Empty | Task template is empty | Task template is empty | Please contact the OceanBase technical support team for troubleshooting. |
